@@ -75,7 +75,7 @@ class Central_widget(QtGui.QWidget):
         self.reload_bonjour_users_button.setIcon(icon)
         self.reload_bonjour_users_button.setFixedWidth(80)
         self.empty = QtGui.QLabel('')
-        self.friend_list_label = QtGui.QLabel('Friends list :')
+        self.friend_list_label = QtGui.QLabel('Friend list :')
         self.friends_list = Friend_list_widget(self)
         mainLayout = QtGui.QGridLayout()
         mainLayout.addWidget(self.bonjour_users_label, 0, 0, 1, 2)
@@ -268,7 +268,7 @@ class Ui_MainWindow(QtCore.QObject):
         icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
                            '/general_refresh.png')
         vars = {}
-        vars['version'] = "1.6.4"
+        vars['version'] = "1.6.7"
         message = QtCore.QString("""<center><h2>HeySms</h2></center>"""
                                  """<center>Version: %(version)s</center>"""
                                  """<br/>Visite web site: <a href="http://talk.maemo.org/showthread.php?t=84705">Here</a> """
@@ -293,6 +293,8 @@ def main():
         ui.scheduler.must_run = False
         while ui.scheduler.isRunning():
             logger.debug("Waiting scheduler")
+            if ui.scheduler.waiting_authorized_contact == True:
+                break
             sleep(0.1)
         logger.debug("Restore profile")
         config.restore_profile()
